/**
 * 演示程序当前的 “注册/登录” 等操作，是基于 “本地存储” 完成的
 * 当您要参考这个演示程序进行相关 app 的开发时，
 * 请注意将相关方法调整成 “基于服务端Service” 的实现。
 **/
(function($, owner) {
    
    // 学校类型列表  根据项目的index值区分
    owner.schoolKinds = ['幼儿园', '小学', '初中', '高中', '大学'];

    // 学校类型对应的班级 
    owner.gradeForKind = [
        ['小班','中班', '大班'],
        ['一年级', '二年级', '三年级', '四年级', '五年级', '六年级'],
        ['七年级', '八年级', '九年级'],
        ['高一', '高二', '高三'],
        ['大一', '大二', '大三', '大四']
    ];
    
    owner.relationList = ["爸爸", "妈妈", "爷爷", "奶奶", "姨夫","姨妈", "姑父", "姑妈", "叔叔", "婶婶", "哥哥", "姐姐", "亲戚", "监护人"];
    
    owner.studentStates  = ['未到校', '迟到', '旷课', '早退', '在校'];
	
	/**
	 * 获取学校列表
	 * @param {Object} data 查询参数
	 * @param {Function} cb 回调函数
	 */
	owner.getSchoolList = function (data, cb) {
	    if(typeof data == 'function') {
	        cb = data;
	        data = {};
	    }
	    var options = Object.assign({
            "paging.mode": 0,
            "paging.first": 0,
            "paging.max": 5
        }, data);
	    
	    Tools.waiting('学校加载中…');
        Tools.getJSON('school.query.action', options, function (data) {
            if(data.result.error) return mui.alert('学校加载失败！');
            Tools.waiting();                            
            cb(data);
        })
	}
	
	/**
     * 获取班级列表
     * @param {Object} data 查询参数
     * @param {Function} cb 回调函数
     */
    owner.getTeamList = function (data, cb) {
        if(typeof data == 'function') {
            cb = data;
            data = {};
        }       
        
        Tools.getJSON('team.query.action?a', data, function (data) {
            if(data.result.error) return mui.alert('学校加载失败！');                        
            cb(data);
        })
    }
    
    /**
     * 添加并绑定学生
     * @param {Object} options
     * @param {Object} cb
     */
    owner.addAndBindStudent = function (options, cb) {
        // 检测字段是否已填        
        if(!options.rltnShip) return mui.alert('请选择与孩子的关系');
        var object = {};
        var self = this;
        
        this.addStudent(options, function (data) {
            if(data.array.length == 0) { // 学生已经注册过
                self.bindStudent(data.object, options.rltnShip, cb);
            } else {
                object = data.array[0];
                
                var msg = '姓名：' + object.studentName + '\r\n性别：' + (object.sex ? '男' :'女') + '\r\n学校：' + object.team.school.schoolName +'\r\n年级：' + object.team.grade + object.team.teamName;
                mui.confirm(msg,'该学生已存在，您要选择的是他么？', '是的', function (e) {
                    if(e.index == 1) return false;  // 取消
                    // 选择该学生， 开始绑定
                    self.bindStudent(object, options.rltnShip, cb);
                })
            }                
        })
    }
    /**
     * 为用户绑定学生  
     * @param {Object} student 学生对象
     * @param {String} rltnShip  学生跟用户之间的关系
     * @param {Object} cb 回调函数
     */
    owner.bindStudent = function (student, rltnShip, cb) {
        var user = Tools.getUser();
        Tools.waiting('正在绑定…');
        Tools.getJSON('link.insert.action', {
            'user.username': user.username,
            'student.id': student.id,
            'rltnShip': rltnShip
        }, function (data) {
            Tools.waiting();
            if(data.result.error) return mui.alert(data.result.info);            
            mui.toast('绑定成功！');
            cb(data);
        })
    }
    /**
     * 解除用户绑定
     * @param {Object} studentId 学生对象
     * @param {String} username 用户
     * @param {Object} cb
     */
    owner.unBindStudent = function (studentId, username, cb) {
        Tools.waiting('处理中…');
        Tools.getJSON('link.delete.action', {
            'student.id': studentId,
            'user.username': username
        }, function (data) {
            Tools.waiting();
            if(data.result.error) return mui.alert(data.result.info);
            
            cb && cb(data);
        })
    }
    
    /**
     * 添加学生
     * @param {Object} student
     * @param {Object} cb
     */
    owner.addStudent = function (student, cb) {
        // 检测字段是否已填
        if(!student.studentName) return mui.alert('学生姓名不能为空');
        if(!student.sex.toString()) return mui.alert('学生性别不能为空');
        if(!student.birthday) return mui.alert('学生生日不能为空');
        if(!student.team.id) return mui.alert('学生班级不能为空');
        Tools.waiting('加载中…');
        Tools.getJSON('student.insert.action', student, function (data) {
            Tools.waiting();
            if(data.result.error && data.result.info !== '数据重复！') return mui.alert(data.result.info);
            cb && cb(data);            
        })
    }
    
    
    /**
     * 选择图片上传  （更改用户头像）
     * @param {Object} options 配置参数
     */
    owner.selectPhoto = function(options) {
        var self = this;
        var buttons = [{
                title: '打开照相机'
            },
            {
                title: '从手机相册获取'
            }
        ];
        var callback = function (path) {
            self._compressImg(path, options);
        }
        plus.nativeUI.actionSheet({
            buttons: buttons,
            cancel: '取消',
        }, function(e) {
            if(e.index === 2) {
                plus.gallery.pick(callback)
            } else if(e.index === 1) {
                var cmr = plus.camera.getCamera();   
                cmr.captureImage(callback)
            }                                
        })

    };
    
    /**
     * 压缩图片
     * @param {String} path 图片路径
     * @param {Object} options 配置参数
     */
    owner._compressImg = function (path, options) {
        var self = this;
        var dst = '_doc/photo.jpg';
        plus.zip.compressImage({
            src: path,
            dst: dst,
            overwrite: true,
            format: 'jpg',
            width: '100px',
            height: '100px'
        }, function (event) {
            self._uploadPhoto(event.target, options);
        }, function (event) {
            console.log('错误了')
        })
    };
    
    /**
     * 上传头像
     * @param {String} path 要上传的头像路径
     */
    owner._uploadPhoto = function (path, options) {
        var self = this;
        var user = options.user;
        
        Tools.waiting('上传中…');
        var task = plus.uploader.createUpload(SERVERURL + 'teacher.update.action?primary=' + user.id, {
            method: 'POST',
            blocksize: 204800,
            priority: 100
        }, function(t, status) {
            Tools.log(t)
            Tools.waiting();
            if(status == 200) {                                            
                var data = JSON.parse(t.responseText);
                if(data.result.error) return options.error(data.result.info);
                options.success(data);                                                                                    
            } else {
                options.error('上传失败！');
            }
        });

        task.addFile(path, {
            key: 'uploads.files'
        });
        task.start();
    }
	
	
	//获取验证码
	var waitTime = 30;
	owner.getCode = function(type, callback) {
		type = type || "";
		var codeUrl;
		if(type == "toRegesiter") {
			codeUrl = 'http://gangcao.support.neol.cc/user_register.action'
		} else if(type == "toForget") {
			codeUrl = 'http://gangcao.support.neol.cc/user_retake.action'
		};
		callback = callback || $.noop;

		var phone = window.document.getElementById('account').value
		if(!phone) { // 判断手机号为空
			return callback('手机号不能为空');
		}
		if(!(/^1[3|4|5|7|8]\d{9}$/.test(phone))) { // 判断手机号规范
			return callback('请正确填写手机号');
		}
		//验证码按钮倒计时
		owner.timeDisplay(window.document.getElementById('code'));
		//访问服务器获取验证码
		owner.sendTheCode(codeUrl, phone);

	};

	//验证码倒计时
	owner.timeDisplay = function(targetBtn) {
		if(waitTime == 0) {
			targetBtn.removeAttribute("disabled");
			targetBtn.innerHTML = "验证码";
			waitTime = 30;
		} else {
			targetBtn.setAttribute("disabled", true);
			targetBtn.innerHTML = waitTime + "秒后重发";
			waitTime--;
			setTimeout(function() {
					owner.timeDisplay(window.document.getElementById('code'));
				},
				1000)
		}

	};

	//发送验证码
	owner.sendTheCode = function(codeUrl, phone) {
		$.getJSON(codeUrl, {
				phone: phone,
			},
			function(data) {
				if(data.result.info) {
					return plus.nativeUI.toast(data.result.info);
				} else {
					codeValue = data.object.verify;
					if(data.array.length > 0) {
						ownerId = data.array[0].id;

					}
				};
			}
		);
	};

	/**
	 * 获取当前状态
	 **/
	owner.getState = function() {
		var stateText = localStorage.getItem('$state') || "{}";
		return JSON.parse(stateText);
	};

	/**
	 * 设置当前状态
	 **/
	owner.setState = function(state) {
		state = state || {};
		localStorage.setItem('$state', JSON.stringify(state));
	};

	/**
	 * 重置密码
	 **/
	owner.resetPassword = function(resetInfo, callback) {
		

		if(JSON.parse(localStorage.getItem("user")).password != resetInfo.oldPassword) {
			return callback('原密码错误');
		};
		//访问服务器修改账号
		mui.getJSON("http://gangcao.support.neol.cc/user_update.action", {
				password: resetInfo.newPassword,
				id: JSON.parse(localStorage.getItem("user")).id
			},

			function(data) {
				if(data.result.info) {
					owner.console(data.result.info);
					return callback(data.result.info);
				} else {
						plus.nativeUI.toast('修改成功，请重新登录');
					localStorage.removeItem("user");
					var parent = plus.webview.getWebviewById("personal.html");
					mui.fire(parent, 'loadingState');
					plus.webview.close(plus.webview.currentWebview());

				};
			}

		)
	};

	/**
	 * 获取应用本地配置
	 **/
	owner.setSettings = function(settings) {
		settings = settings || {};
		localStorage.setItem('$settings', JSON.stringify(settings));
	}

	/**
	 * 设置应用本地配置
	 **/
	owner.getSettings = function() {
			var settingsText = localStorage.getItem('$settings') || "{}";
			return JSON.parse(settingsText);
		}
		/**
		 * 获取本地是否安装客户端
		 **/
	owner.isInstalled = function(id) {
		if(id === 'qihoo' && mui.os.plus) {
			return true;
		}
		if(mui.os.android) {
			var main = plus.android.runtimeMainActivity();
			var packageManager = main.getPackageManager();
			var PackageManager = plus.android.importClass(packageManager)
			var packageName = {
				"qq": "com.tencent.mobileqq",
				"weixin": "com.tencent.mm",
				"sinaweibo": "com.sina.weibo"
			}
			try {
				return packageManager.getPackageInfo(packageName[id], PackageManager.GET_ACTIVITIES);
			} catch(e) {}
		} else {
			switch(id) {
				case "qq":
					var TencentOAuth = plus.ios.import("TencentOAuth");
					return TencentOAuth.iphoneQQInstalled();
				case "weixin":
					var WXApi = plus.ios.import("WXApi");
					return WXApi.isWXAppInstalled()
				case "sinaweibo":
					var SinaAPI = plus.ios.import("WeiboSDK");
					return SinaAPI.isWeiboAppInstalled()
				default:
					break;
			}
		}
	}
}(mui, window.app = {}));